%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                  autor: Danilo Couto de Souza                     %%%%
%%%%                            PPGOceano                              %%%%
%%%%                                                                   %%%%
%%%%                 Script para validar dados do OLAM                 %%%%
%%%%                                                                   %%%% 
%%%%                       18 de Maro de 2019                         %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc
clear

load Dados_INMET_3xdia.txt
dadosI3 = Dados_INMET_3xdia;

load Dados_INMET_diarios.txt
dadosId = Dados_INMET_diarios;

load Dados_OLAM_3xdia.txt
dadosO3 = Dados_OLAM_3xdia;

load Dados_OLAM_diarios.txt
dadosOd = Dados_OLAM_diarios;

%% Siglas

% Variveis:
% p = precipitao, t = temperatura, vv = velocidade do vento, dv = direo
% do vento, ac = precipitao acumulada

% Fonte de dados:
%i = inmet, o = olam

% Cidades:
% pga = Paranagu, fps = Florianopolis, trs = Torres, rgd = Rio Grande,
% svp = Santa Vitoria do Palmar

% Eventos (e) vo ser nomeados de 1 a 12, do mais recente para o mais antigo,
% ex: e1 = 10 a 16 de janeiro de 2018

%% Criando vetor pra chamar as datas de um evento

% Para dados dirios:

ed1 = 1:7;
ed2 = 8:14;
ed3 = 15:18;
ed4 = 19:24;
ed5 = 25:30;
ed6 = 31:33;
ed7 = 34:41;
ed8 = 42:44;
ed9 = 45:47;
ed10 = 48:53;
ed11 = 54:59;
ed12 = 60:70;

% Para dados 3x ao dia:

eh1 = 1:21;
eh2 = 22:42;
eh3 = 43:54;
eh4 = 55:72;
eh5 = 73:90;
eh6 = 91:99;
eh7 = 100:123;
eh8 = 124:132;
eh9 = 133:141;
eh10 = 142:159;
eh11 = 160:177;
eh12 = 178:210;

%% Dados de precipitao

% Precipitao possui apenas dados dirios

datas_diario = dadosId(1:2:end,1);

% Agrupando dados por cidade e fonte

pIpga = dadosId(2:2:end,3);
pOpga = dadosOd(:,4);

pIfps = dadosId(2:2:end,8);
pOfps = dadosOd(:,6);

pItrs = dadosId(2:2:end,13);
pOtrs = dadosOd(:,8);

pIrgd = dadosId(2:2:end,18);
pOrgd = dadosOd(:,10);

pIsvp = dadosId(2:2:end,23);
pOsvp = dadosOd(:,12);

%% Dados de precipitao acumulada

acpIpga = [cumsum(pIpga(ed1)); cumsum(pIpga(ed2)); cumsum(pIpga(ed3));
    cumsum(pIpga(ed4)); cumsum(pIpga(ed5)); cumsum(pIpga(ed6)); 
    cumsum(pIpga(ed7)); cumsum(pIpga(ed8)); cumsum(pIpga(ed9));
    cumsum(pIpga(ed10)); cumsum(pIpga(ed11)); cumsum(pIpga(ed12))];

acpIfps = [cumsum(pIfps(ed1)); cumsum(pIfps(ed2)); cumsum(pIfps(ed3));
    cumsum(pIfps(ed4)); cumsum(pIfps(ed5)); cumsum(pIfps(ed6)); 
    cumsum(pIfps(ed7)); cumsum(pIfps(ed8)); cumsum(pIfps(ed9));
    cumsum(pIfps(ed10)); cumsum(pIfps(ed11)); cumsum(pIfps(ed12))];

acpItrs = [cumsum(pItrs(ed1)); cumsum(pItrs(ed2)); cumsum(pItrs(ed3));
    cumsum(pItrs(ed4)); cumsum(pItrs(ed5)); cumsum(pItrs(ed6)); 
    cumsum(pItrs(ed7)); cumsum(pItrs(ed8)); cumsum(pItrs(ed9));
    cumsum(pItrs(ed10)); cumsum(pItrs(ed11)); cumsum(pItrs(ed12))];

acpIrgd = [cumsum(pIrgd(ed1)); cumsum(pIrgd(ed2)); cumsum(pIrgd(ed3));
    cumsum(pIrgd(ed4)); cumsum(pIrgd(ed5)); cumsum(pIrgd(ed6)); 
    cumsum(pIrgd(ed7)); cumsum(pIrgd(ed8)); cumsum(pIrgd(ed9));
    cumsum(pIrgd(ed10)); cumsum(pIrgd(ed11)); cumsum(pIrgd(ed12))];

acpIsvp = [cumsum(pIsvp(ed1)); cumsum(pIsvp(ed2)); cumsum(pIsvp(ed3));
    cumsum(pIsvp(ed4)); cumsum(pIsvp(ed5)); cumsum(pIsvp(ed6)); 
    cumsum(pIsvp(ed7)); cumsum(pIsvp(ed8)); cumsum(pIsvp(ed9));
    cumsum(pIsvp(ed10)); cumsum(pIsvp(ed11)); cumsum(pIsvp(ed12))];



acpOpga = dadosOd(:,3);
acpOfps = dadosOd(:,5);
acpOtrs = dadosOd(:,7);
acpOrgd = dadosOd(:,9);
acpOsvp = dadosOd(:,11);
%% Criando vetor de tempo para dados de temperatura e vento

% Temperatura e ventos possuem dados para 00h 12h e 18h

datas_3xdia = dadosI3(:,1);

% Loop para adcionar decimais aos dias p/ facilitar plotagem

datas_hora = datas_3xdia;

for i=2:3:length(datas_3xdia);
    datas_hora(i) = datas_3xdia(i)+0.5;
end
for i=3:3:length(datas_3xdia);
    datas_hora(i) = datas_3xdia(i)+0.75;
end

%% Temperatura

% Agrupando dados por cidade e fonte

tIpga = dadosI3(:,3);
tOpga = dadosO3(:,3);

tIfps = dadosI3(:,8);
tOfps = dadosO3(:,6);

tItrs = dadosI3(:,13);
tOtrs = dadosO3(:,9);

tIrgd = dadosI3(:,18);
tOrgd = dadosO3(:,12);

tIsvp = dadosI3(:,23);
tOsvp = dadosO3(:,15);

%% Velocidade do vento

% Velocidade do vento possui dados para 00h 12h e 18h

vvIpga = dadosI3(:,7);
vvOpga = dadosO3(:,5);

vvIfps = dadosI3(:,12);
vvOfps = dadosO3(:,8);

vvItrs = dadosI3(:,17);
vvOtrs = dadosO3(:,11);

vvIrgd = dadosI3(:,22);
vvOrgd = dadosO3(:,14);

vvIsvp = dadosI3(:,27);
vvOsvp = dadosO3(:,17);


%% Direcao do vento

% Direcao do vento possui dados para 00h 12h e 18h

dvIpga = dadosI3(:,6);
dvOpga = dadosO3(:,4);

dvIfps = dadosI3(:,11);
dvOfps = dadosO3(:,7);

dvItrs = dadosI3(:,16);
dvOtrs = dadosO3(:,10);

dvIrgd = dadosI3(:,21);
dvOrgd = dadosO3(:,13);

dvIsvp = dadosI3(:,26);
dvOsvp = dadosO3(:,16);

%% Mapa de cores: greyscale

c = gray(20);

% %% Graficos de precipitao
% 
% 
% % Paranagua
% figure(1)
% clf
% title('Paranagua')
% % Evento 1
% subplot(3,4,1)
% plot(datas_diario(ed1,1),pIpga(ed1,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed1,1),pOpga(ed1,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 1')
% legend('INMET','OLAM')
% hold off
% % Evento 2
% subplot(3,4,2)
% plot(datas_diario(ed2,1),pIpga(ed2,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed2,1),pOpga(ed2,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 2')
% hold off
% % Evento 3
% subplot(3,4,3)
% plot(datas_diario(ed3,1),pIpga(ed3,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed3,1),pOpga(ed3,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 3')
% hold off
% % Evento 4
% subplot(3,4,4)
% plot(datas_diario(ed4,1),pIpga(ed4,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed4,1),pOpga(ed4,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 4')
% hold off
% % Evento 5
% subplot(3,4,5)
% plot(datas_diario(ed5,1),pIpga(ed5,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed5,1),pOpga(ed5,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 5')
% hold off
% % Evento 6
% subplot(3,4,6)
% plot(datas_diario(ed6,1),pIpga(ed6,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed6,1),pOpga(ed6,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 6')
% hold off
% % Evento 7
% subplot(3,4,7)
% plot(datas_diario(ed7,1),pIpga(ed7,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed7,1),pOpga(ed7,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 7')
% hold off
% % Evento 8
% subplot(3,4,8)
% plot(datas_diario(ed8,1),pIpga(ed8,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed8,1),pOpga(ed8,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 8')
% hold off
% % Evento 9
% subplot(3,4,9)
% plot(datas_diario(ed9,1),pIpga(ed9,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed9,1),pOpga(ed9,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 9')
% hold off
% % Evento 10
% subplot(3,4,10)
% plot(datas_diario(ed10,1),pIpga(ed10,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed10,1),pOpga(ed10,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 10')
% hold off
% % Evento 11
% subplot(3,4,11)
% plot(datas_diario(ed11,1),pIpga(ed11,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed11,1),pOpga(ed11,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 11')
% hold off
% % Evento 12
% subplot(3,4,12)
% plot(datas_diario(ed12,1),pIpga(ed12,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed12,1),pOpga(ed12,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 12')
% hold off
% 
% % Florianopolis
% figure(2)
% clf
% title('Florianopolis')
% % Evento 1
% subplot(3,4,1)
% plot(datas_diario(ed1,1),pIfps(ed1,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed1,1),pOfps(ed1,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 1')
% legend('INMET','OLAM')
% hold off
% % Evento 2
% subplot(3,4,2)
% plot(datas_diario(ed2,1),pIfps(ed2,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed2,1),pOfps(ed2,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 2')
% hold off
% % Evento 3
% subplot(3,4,3)
% plot(datas_diario(ed3,1),pIfps(ed3,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed3,1),pOfps(ed3,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 3')
% hold off
% % Evento 4
% subplot(3,4,4)
% plot(datas_diario(ed4,1),pIfps(ed4,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed4,1),pOfps(ed4,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 4')
% hold off
% % Evento 5
% subplot(3,4,5)
% plot(datas_diario(ed5,1),pIfps(ed5,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed5,1),pOfps(ed5,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 5')
% hold off
% % Evento 6
% subplot(3,4,6)
% plot(datas_diario(ed6,1),pIfps(ed6,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed6,1),pOfps(ed6,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 6')
% hold off
% % Evento 7
% subplot(3,4,7)
% plot(datas_diario(ed7,1),pIfps(ed7,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed7,1),pOfps(ed7,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 7')
% hold off
% % Evento 8
% subplot(3,4,8)
% plot(datas_diario(ed8,1),pIfps(ed8,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed8,1),pOfps(ed8,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 8')
% hold off
% % Evento 9
% subplot(3,4,9)
% plot(datas_diario(ed9,1),pIfps(ed9,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed9,1),pOfps(ed9,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 9')
% hold off
% % Evento 10
% subplot(3,4,10)
% plot(datas_diario(ed10,1),pIfps(ed10,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed10,1),pOfps(ed10,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 10')
% hold off
% % Evento 11
% subplot(3,4,11)
% plot(datas_diario(ed11,1),pIfps(ed11,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed11,1),pOfps(ed11,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 11')
% hold off
% % Evento 12
% subplot(3,4,12)
% plot(datas_diario(ed12,1),pIfps(ed12,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed12,1),pOfps(ed12,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 12')
% hold off
% 
% % Torres
% figure(3)
% clf
% title('Torres')
% % Evento 1
% subplot(3,4,1)
% plot(datas_diario(ed1,1),pItrs(ed1,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed1,1),pOtrs(ed1,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 1')
% legend('INMET','OLAM')
% hold off
% % Evento 2
% subplot(3,4,2)
% plot(datas_diario(ed2,1),pItrs(ed2,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed2,1),pOtrs(ed2,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 2')
% hold off
% % Evento 3
% subplot(3,4,3)
% plot(datas_diario(ed3,1),pItrs(ed3,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed3,1),pOtrs(ed3,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 3')
% hold off
% % Evento 4
% subplot(3,4,4)
% plot(datas_diario(ed4,1),pItrs(ed4,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed4,1),pOtrs(ed4,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 4')
% hold off
% % Evento 5
% subplot(3,4,5)
% plot(datas_diario(ed5,1),pItrs(ed5,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed5,1),pOtrs(ed5,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 5')
% hold off
% % Evento 6
% subplot(3,4,6)
% plot(datas_diario(ed6,1),pItrs(ed6,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed6,1),pOtrs(ed6,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 6')
% hold off
% % Evento 7
% subplot(3,4,7)
% plot(datas_diario(ed7,1),pItrs(ed7,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed7,1),pOtrs(ed7,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 7')
% hold off
% % Evento 8
% subplot(3,4,8)
% plot(datas_diario(ed8,1),pItrs(ed8,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed8,1),pOtrs(ed8,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 8')
% hold off
% % Evento 9
% subplot(3,4,9)
% plot(datas_diario(ed9,1),pItrs(ed9,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed9,1),pOtrs(ed9,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 9')
% hold off
% % Evento 10
% subplot(3,4,10)
% plot(datas_diario(ed10,1),pItrs(ed10,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed10,1),pOtrs(ed10,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 10')
% hold off
% % Evento 11
% subplot(3,4,11)
% plot(datas_diario(ed11,1),pItrs(ed11,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed11,1),pOtrs(ed11,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 11')
% hold off
% % Evento 12
% subplot(3,4,12)
% plot(datas_diario(ed12,1),pItrs(ed12,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed12,1),pOtrs(ed12,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 12')
% hold off
% 
% % Rio Grande
% figure(4)
% clf
% title('Rio Grande')
% % Evento 1
% subplot(3,4,1)
% plot(datas_diario(ed1,1),pIrgd(ed1,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed1,1),pOrgd(ed1,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 1')
% legend('INMET','OLAM')
% hold off
% % Evento 2
% subplot(3,4,2)
% plot(datas_diario(ed2,1),pIrgd(ed2,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed2,1),pOrgd(ed2,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 2')
% hold off
% % Evento 3
% subplot(3,4,3)
% plot(datas_diario(ed3,1),pIrgd(ed3,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed3,1),pOrgd(ed3,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 3')
% hold off
% % Evento 4
% subplot(3,4,4)
% plot(datas_diario(ed4,1),pIrgd(ed4,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed4,1),pOrgd(ed4,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 4')
% hold off
% % Evento 5
% subplot(3,4,5)
% plot(datas_diario(ed5,1),pIrgd(ed5,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed5,1),pOrgd(ed5,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 5')
% hold off
% % Evento 6
% subplot(3,4,6)
% plot(datas_diario(ed6,1),pIrgd(ed6,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed6,1),pOrgd(ed6,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 6')
% hold off
% % Evento 7
% subplot(3,4,7)
% plot(datas_diario(ed7,1),pIrgd(ed7,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed7,1),pOrgd(ed7,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 7')
% hold off
% % Evento 8
% subplot(3,4,8)
% plot(datas_diario(ed8,1),pIrgd(ed8,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed8,1),pOrgd(ed8,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 8')
% hold off
% % Evento 9
% subplot(3,4,9)
% plot(datas_diario(ed9,1),pIrgd(ed9,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed9,1),pOrgd(ed9,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 9')
% hold off
% % Evento 10
% subplot(3,4,10)
% plot(datas_diario(ed10,1),pIrgd(ed10,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed10,1),pOrgd(ed10,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 10')
% hold off
% % Evento 11
% subplot(3,4,11)
% plot(datas_diario(ed11,1),pIrgd(ed11,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed11,1),pOrgd(ed11,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 11')
% hold off
% % Evento 12
% subplot(3,4,12)
% plot(datas_diario(ed12,1),pIrgd(ed12,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed12,1),pOrgd(ed12,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 12')
% hold off
% 
% % Santa Vitoria do Palmar
% figure(5)
% clf
% title('Santa Vitoria do Palmar')
% % Evento 1
% subplot(3,4,1)
% plot(datas_diario(ed1,1),pIsvp(ed1,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed1,1),pOsvp(ed1,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 1')
% legend('INMET','OLAM')
% hold off
% % Evento 2
% subplot(3,4,2)
% plot(datas_diario(ed2,1),pIsvp(ed2,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed2,1),pOsvp(ed2,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 2')
% hold off
% % Evento 3
% subplot(3,4,3)
% plot(datas_diario(ed3,1),pIsvp(ed3,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed3,1),pOsvp(ed3,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 3')
% hold off
% % Evento 4
% subplot(3,4,4)
% plot(datas_diario(ed4,1),pIsvp(ed4,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed4,1),pOsvp(ed4,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 4')
% hold off
% % Evento 5
% subplot(3,4,5)
% plot(datas_diario(ed5,1),pIsvp(ed5,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed5,1),pOsvp(ed5,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 5')
% hold off
% % Evento 6
% subplot(3,4,6)
% plot(datas_diario(ed6,1),pIsvp(ed6,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed6,1),pOsvp(ed6,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 6')
% hold off
% % Evento 7
% subplot(3,4,7)
% plot(datas_diario(ed7,1),pIsvp(ed7,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed7,1),pOsvp(ed7,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 7')
% hold off
% % Evento 8
% subplot(3,4,8)
% plot(datas_diario(ed8,1),pIsvp(ed8,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed8,1),pOsvp(ed8,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 8')
% hold off
% % Evento 9
% subplot(3,4,9)
% plot(datas_diario(ed9,1),pIsvp(ed9,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed9,1),pOsvp(ed9,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 9')
% hold off
% % Evento 10
% subplot(3,4,10)
% plot(datas_diario(ed10,1),pIsvp(ed10,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed10,1),pOsvp(ed10,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 10')
% hold off
% % Evento 11
% subplot(3,4,11)
% plot(datas_diario(ed11,1),pIsvp(ed11,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed11,1),pOsvp(ed11,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 11')
% hold off
% % Evento 12
% subplot(3,4,12)
% plot(datas_diario(ed12,1),pIsvp(ed12,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_diario(ed12,1),pOsvp(ed12,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 12')
% hold off
% 
% 
% %% Grfico de temperatura
% 
% % Paranagua
% figure(6)
% clf
% title('Paranagua')
% % Evento 1
% subplot(3,4,1)
% plot(datas_hora(eh1,1),tIpga(eh1,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh1,1),tOpga(eh1,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 1')
% legend('INMET','OLAM')
% hold off
% % Evento 2
% subplot(3,4,2)
% plot(datas_hora(eh2,1),tIpga(eh2,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh2,1),tOpga(eh2,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 2')
% hold off
% % Evento 3
% subplot(3,4,3)
% plot(datas_hora(eh3,1),tIpga(eh3,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh3,1),tOpga(eh3,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 3')
% hold off
% % Evento 4
% subplot(3,4,4)
% plot(datas_hora(eh4,1),tIpga(eh4,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh4,1),tOpga(eh4,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 4')
% hold off
% % Evento 5
% subplot(3,4,5)
% plot(datas_hora(eh5,1),tIpga(eh5,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh5,1),tOpga(eh5,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 5')
% hold off
% % Evento 6
% subplot(3,4,6)
% plot(datas_hora(eh6,1),tIpga(eh6,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh6,1),tOpga(eh6,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 6')
% hold off
% % Evento 7
% subplot(3,4,7)
% plot(datas_hora(eh7,1),tIpga(eh7,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh7,1),tOpga(eh7,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 7')
% hold off
% % Evento 8
% subplot(3,4,8)
% plot(datas_hora(eh8,1),tIpga(eh8,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh8,1),tOpga(eh8,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 8')
% hold off
% % Evento 9
% subplot(3,4,9)
% plot(datas_hora(eh9,1),tIpga(eh9,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh9,1),tOpga(eh9,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 9')
% hold off
% % Evento 10
% subplot(3,4,10)
% plot(datas_hora(eh10,1),tIpga(eh10,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh10,1),tOpga(eh10,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 10')
% hold off
% % Evento 11
% subplot(3,4,11)
% plot(datas_hora(eh11,1),tIpga(eh11,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh11,1),tOpga(eh11,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 11')
% hold off
% % Evento 12
% subplot(3,4,12)
% plot(datas_hora(eh12,1),tIpga(eh12,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh12,1),tOpga(eh12,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 12')
% hold off
% 
% % Florianopolis
% figure(7)
% clf
% title('FlorianotOlis')
% % Evento 1
% subplot(3,4,1)
% plot(datas_hora(eh1,1),tIfps(eh1,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh1,1),tOfps(eh1,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 1')
% legend('INMET','OLAM')
% hold off
% % Evento 2
% subplot(3,4,2)
% plot(datas_hora(eh2,1),tIfps(eh2,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh2,1),tOfps(eh2,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 2')
% hold off
% % Evento 3
% subplot(3,4,3)
% plot(datas_hora(eh3,1),tIfps(eh3,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh3,1),tOfps(eh3,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 3')
% hold off
% % Evento 4
% subplot(3,4,4)
% plot(datas_hora(eh4,1),tIfps(eh4,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh4,1),tOfps(eh4,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 4')
% hold off
% % Evento 5
% subplot(3,4,5)
% plot(datas_hora(eh5,1),tIfps(eh5,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh5,1),tOfps(eh5,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 5')
% hold off
% % Evento 6
% subplot(3,4,6)
% plot(datas_hora(eh6,1),tIfps(eh6,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh6,1),tOfps(eh6,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 6')
% hold off
% % Evento 7
% subplot(3,4,7)
% plot(datas_hora(eh7,1),tIfps(eh7,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh7,1),tOfps(eh7,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 7')
% hold off
% % Evento 8
% subplot(3,4,8)
% plot(datas_hora(eh8,1),tIfps(eh8,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh8,1),tOfps(eh8,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 8')
% hold off
% % Evento 9
% subplot(3,4,9)
% plot(datas_hora(eh9,1),tIfps(eh9,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh9,1),tOfps(eh9,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 9')
% hold off
% % Evento 10
% subplot(3,4,10)
% plot(datas_hora(eh10,1),tIfps(eh10,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh10,1),tOfps(eh10,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 10')
% hold off
% % Evento 11
% subplot(3,4,11)
% plot(datas_hora(eh11,1),tIfps(eh11,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh11,1),tOfps(eh11,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 11')
% hold off
% % Evento 12
% subplot(3,4,12)
% plot(datas_hora(eh12,1),tIfps(eh12,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh12,1),tOfps(eh12,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 12')
% hold off
% 
% % Torres
% figure(8)
% clf
% title('Torres')
% % Evento 1
% subplot(3,4,1)
% plot(datas_hora(eh1,1),tItrs(eh1,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh1,1),tOtrs(eh1,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 1')
% legend('INMET','OLAM')
% hold off
% % Evento 2
% subplot(3,4,2)
% plot(datas_hora(eh2,1),tItrs(eh2,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh2,1),tOtrs(eh2,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 2')
% hold off
% % Evento 3
% subplot(3,4,3)
% plot(datas_hora(eh3,1),tItrs(eh3,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh3,1),tOtrs(eh3,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 3')
% hold off
% % Evento 4
% subplot(3,4,4)
% plot(datas_hora(eh4,1),tItrs(eh4,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh4,1),tOtrs(eh4,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 4')
% hold off
% % Evento 5
% subplot(3,4,5)
% plot(datas_hora(eh5,1),tItrs(eh5,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh5,1),tOtrs(eh5,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 5')
% hold off
% % Evento 6
% subplot(3,4,6)
% plot(datas_hora(eh6,1),tItrs(eh6,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh6,1),tOtrs(eh6,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 6')
% hold off
% % Evento 7
% subplot(3,4,7)
% plot(datas_hora(eh7,1),tItrs(eh7,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh7,1),tOtrs(eh7,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 7')
% hold off
% % Evento 8
% subplot(3,4,8)
% plot(datas_hora(eh8,1),tItrs(eh8,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh8,1),tOtrs(eh8,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 8')
% hold off
% % Evento 9
% subplot(3,4,9)
% plot(datas_hora(eh9,1),tItrs(eh9,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh9,1),tOtrs(eh9,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 9')
% hold off
% % Evento 10
% subplot(3,4,10)
% plot(datas_hora(eh10,1),tItrs(eh10,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh10,1),tOtrs(eh10,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 10')
% hold off
% % Evento 11
% subplot(3,4,11)
% plot(datas_hora(eh11,1),tItrs(eh11,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh11,1),tOtrs(eh11,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 11')
% hold off
% % Evento 12
% subplot(3,4,12)
% plot(datas_hora(eh12,1),tItrs(eh12,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh12,1),tOtrs(eh12,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 12')
% hold off
% 
% % Rio Grande
% figure(9)
% clf
% title('Rio Grande')
% % Evento 1
% subplot(3,4,1)
% plot(datas_hora(eh1,1),tIrgd(eh1,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh1,1),tOrgd(eh1,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 1')
% legend('INMET','OLAM')
% hold off
% % Evento 2
% subplot(3,4,2)
% plot(datas_hora(eh2,1),tIrgd(eh2,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh2,1),tOrgd(eh2,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 2')
% hold off
% % Evento 3
% subplot(3,4,3)
% plot(datas_hora(eh3,1),tIrgd(eh3,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh3,1),tOrgd(eh3,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 3')
% hold off
% % Evento 4
% subplot(3,4,4)
% plot(datas_hora(eh4,1),tIrgd(eh4,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh4,1),tOrgd(eh4,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 4')
% hold off
% % Evento 5
% subplot(3,4,5)
% plot(datas_hora(eh5,1),tIrgd(eh5,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh5,1),tOrgd(eh5,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 5')
% hold off
% % Evento 6
% subplot(3,4,6)
% plot(datas_hora(eh6,1),tIrgd(eh6,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh6,1),tOrgd(eh6,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 6')
% hold off
% % Evento 7
% subplot(3,4,7)
% plot(datas_hora(eh7,1),tIrgd(eh7,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh7,1),tOrgd(eh7,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 7')
% hold off
% % Evento 8
% subplot(3,4,8)
% plot(datas_hora(eh8,1),tIrgd(eh8,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh8,1),tOrgd(eh8,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 8')
% hold off
% % Evento 9
% subplot(3,4,9)
% plot(datas_hora(eh9,1),tIrgd(eh9,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh9,1),tOrgd(eh9,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 9')
% hold off
% % Evento 10
% subplot(3,4,10)
% plot(datas_hora(eh10,1),tIrgd(eh10,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh10,1),tOrgd(eh10,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 10')
% hold off
% % Evento 11
% subplot(3,4,11)
% plot(datas_hora(eh11,1),tIrgd(eh11,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh11,1),tOrgd(eh11,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 11')
% hold off
% % Evento 12
% subplot(3,4,12)
% plot(datas_hora(eh12,1),tIrgd(eh12,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh12,1),tOrgd(eh12,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 12')
% hold off
% 
% % Santa Vitoria do Palmar
% figure(10)
% clf
% title('Santa Vitoria do Palmar')
% % Evento 1
% subplot(3,4,1)
% plot(datas_hora(eh1,1),tIsvp(eh1,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh1,1),tOsvp(eh1,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 1')
% legend('INMET','OLAM')
% hold off
% % Evento 2
% subplot(3,4,2)
% plot(datas_hora(eh2,1),tIsvp(eh2,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh2,1),tOsvp(eh2,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 2')
% hold off
% % Evento 3
% subplot(3,4,3)
% plot(datas_hora(eh3,1),tIsvp(eh3,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh3,1),tOsvp(eh3,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 3')
% hold off
% % Evento 4
% subplot(3,4,4)
% plot(datas_hora(eh4,1),tIsvp(eh4,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh4,1),tOsvp(eh4,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 4')
% hold off
% % Evento 5
% subplot(3,4,5)
% plot(datas_hora(eh5,1),tIsvp(eh5,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh5,1),tOsvp(eh5,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 5')
% hold off
% % Evento 6
% subplot(3,4,6)
% plot(datas_hora(eh6,1),tIsvp(eh6,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh6,1),tOsvp(eh6,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 6')
% hold off
% % Evento 7
% subplot(3,4,7)
% plot(datas_hora(eh7,1),tIsvp(eh7,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh7,1),tOsvp(eh7,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 7')
% hold off
% % Evento 8
% subplot(3,4,8)
% plot(datas_hora(eh8,1),tIsvp(eh8,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh8,1),tOsvp(eh8,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 8')
% hold off
% % Evento 9
% subplot(3,4,9)
% plot(datas_hora(eh9,1),tIsvp(eh9,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh9,1),tOsvp(eh9,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 9')
% hold off
% % Evento 10
% subplot(3,4,10)
% plot(datas_hora(eh10,1),tIsvp(eh10,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh10,1),tOsvp(eh10,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 10')
% hold off
% % Evento 11
% subplot(3,4,11)
% plot(datas_hora(eh11,1),tIsvp(eh11,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh11,1),tOsvp(eh11,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 11')
% hold off
% % Evento 12
% subplot(3,4,12)
% plot(datas_hora(eh12,1),tIsvp(eh12,1),'-o','color',c(1,:),'linewidth',2);
% hold on
% plot(datas_hora(eh12,1),tOsvp(eh12,1),'--s','color',c(5,:),'linewidth',2);
% title('Event 12')
% hold off

%% Modelado x Observado (Temperatura)

figure (11)
clf

subplot_tight(1,2,1,[0.08 0.08])
hold on

% Evento 1
ax1 = plot(tIpga(eh1,1),tOpga(eh1,1),'o','color',c(2,:));
plot(tIfps(eh1,1),tOfps(eh1,1),'o','color',c(2,:))
plot(tItrs(eh1,1),tOtrs(eh1,1),'o','color',c(2,:))
plot(tIrgd(eh1,1),tOrgd(eh1,1),'o','color',c(2,:))
plot(tIsvp(eh1,1),tOsvp(eh1,1),'o','color',c(2,:))
% Evento 2
ax2 = plot(tIpga(eh2,1),tOpga(eh2,1),'s','color',c(2,:));
plot(tIfps(eh2,1),tOfps(eh2,1),'s','color',c(2,:))
plot(tItrs(eh2,1),tOtrs(eh2,1),'s','color',c(2,:))
plot(tIrgd(eh2,1),tOrgd(eh2,1),'s','color',c(2,:))
plot(tIsvp(eh2,1),tOsvp(eh2,1),'s','color',c(2,:))
% Evento 3
ax3 = plot(tIpga(eh3,1),tOpga(eh3,1),'d','color',c(2,:));
plot(tIfps(eh3,1),tOfps(eh3,1),'d','color',c(2,:))
plot(tItrs(eh3,1),tOtrs(eh3,1),'d','color',c(2,:))
plot(tIrgd(eh3,1),tOrgd(eh3,1),'d','color',c(2,:))
plot(tIsvp(eh3,1),tOsvp(eh3,1),'d','color',c(2,:))
% Evento 4
ax4 = plot(tIpga(eh4,1),tOpga(eh4,1),'<','color',c(2,:));
plot(tIfps(eh4,1),tOfps(eh4,1),'<','color',c(2,:))
plot(tItrs(eh4,1),tOtrs(eh4,1),'<','color',c(2,:))
plot(tIrgd(eh4,1),tOrgd(eh4,1),'<','color',c(2,:))
plot(tIsvp(eh4,1),tOsvp(eh4,1),'<','color',c(2,:))
% Evento 5
ax5 = plot(tIpga(eh5,1),tOpga(eh5,1),'*','color',c(2,:));
plot(tIfps(eh5,1),tOfps(eh5,1),'*','color',c(2,:))
plot(tItrs(eh5,1),tOtrs(eh5,1),'*','color',c(2,:))
plot(tIrgd(eh5,1),tOrgd(eh5,1),'*','color',c(2,:))
plot(tIsvp(eh5,1),tOsvp(eh5,1),'*','color',c(2,:))
% Evento 6
ax6 = plot(tIpga(eh6,1),tOpga(eh6,1),'h','color',c(2,:));
plot(tIfps(eh6,1),tOfps(eh6,1),'h','color',c(2,:))
plot(tItrs(eh6,1),tOtrs(eh6,1),'h','color',c(2,:))
plot(tIrgd(eh6,1),tOrgd(eh6,1),'h','color',c(2,:))
plot(tIsvp(eh6,1),tOsvp(eh6,1),'h','color',c(2,:))
% Evento 7
ax7 = plot(tIpga(eh7,1),tOpga(eh7,1),'+','color',c(2,:));
plot(tIfps(eh7,1),tOfps(eh7,1),'+','color',c(2,:))
plot(tItrs(eh7,1),tOtrs(eh7,1),'+','color',c(2,:))
plot(tIrgd(eh7,1),tOrgd(eh7,1),'+','color',c(2,:))
plot(tIsvp(eh7,1),tOsvp(eh7,1),'+','color',c(2,:))
% Evento 8
ax8 = plot(tIpga(eh8,1),tOpga(eh8,1),'.','color',c(2,:));
plot(tIfps(eh8,1),tOfps(eh8,1),'.','color',c(2,:))
plot(tItrs(eh8,1),tOtrs(eh8,1),'.','color',c(2,:))
plot(tIrgd(eh8,1),tOrgd(eh8,1),'.','color',c(2,:))
plot(tIsvp(eh8,1),tOsvp(eh8,1),'.','color',c(2,:))
% Evento 9
ax9 = plot(tIpga(eh9,1),tOpga(eh9,1),'x','color',c(2,:));
plot(tIfps(eh9,1),tOfps(eh9,1),'x','color',c(2,:))
plot(tItrs(eh9,1),tOtrs(eh9,1),'x','color',c(2,:))
plot(tIrgd(eh9,1),tOrgd(eh9,1),'x','color',c(2,:))
plot(tIsvp(eh9,1),tOsvp(eh9,1),'x','color',c(2,:))
% Evento 10
ax10 = plot(tIpga(eh10,1),tOpga(eh10,1),'^','color',c(2,:));
plot(tIfps(eh10,1),tOfps(eh10,1),'^','color',c(2,:))
plot(tItrs(eh10,1),tOtrs(eh10,1),'^','color',c(2,:))
plot(tIrgd(eh10,1),tOrgd(eh10,1),'^','color',c(2,:))
plot(tIsvp(eh10,1),tOsvp(eh10,1),'^','color',c(2,:))
% Evento 11
ax11 = plot(tIpga(eh11,1),tOpga(eh11,1),'v','color',c(2,:));
plot(tIfps(eh11,1),tOfps(eh11,1),'v','color',c(2,:))
plot(tItrs(eh11,1),tOtrs(eh11,1),'v','color',c(2,:))
plot(tIrgd(eh11,1),tOrgd(eh11,1),'v','color',c(2,:))
plot(tIsvp(eh11,1),tOsvp(eh11,1),'v','color',c(2,:))
% Evento 12
ax12 = plot(tIpga(eh12,1),tOpga(eh12,1),'p','color',c(2,:));
plot(tIfps(eh12,1),tOfps(eh12,1),'p','color',c(2,:))
plot(tItrs(eh12,1),tOtrs(eh12,1),'p','color',c(2,:))
plot(tIrgd(eh12,1),tOrgd(eh12,1),'p','color',c(2,:))
plot(tIsvp(eh12,1),tOsvp(eh12,1),'p','color',c(2,:))

lgd = legend([ax1 ax2 ax3 ax4 ax5 ax6 ax7 ax8 ax9 ax10 ax11 ax12], ...
    {'Event 1', 'Event 2', 'Event 3', 'Event 4', 'Event 5', ...
     'Event 6', 'Event 7', 'Event 8', 'Event 9', 'Event 10', ...
      'Event 11', 'Event 12'}, 'Location','southeast');

xlabel('Observation','fontsize',18)
ylabel('Model','fontsize',18)
title('Temperature Data (C)','fontsize',18)

a = get(gca,'XTickLabel');
set(gca,'fontsize',18)
set(gca,'XLim',[0 35])
set(gca,'XTick',(0:5:35))

% Regresso Linear
% 
% tI = [tIpga; tIfps; tItrs; tIrgd; tIsvp];
% tI(isnan(tI)) = 0;
% 
% tO = [tOpga; tOfps; tOtrs; tOrgd; tOsvp];
% B =  tI\tO;
% B1 =  tI*B;
% plot(tI,B1,'k')
% text(31,9.5,'r^2 = 0.9670')

% Linha de tendncia

Lin = linspace(0,35);

plot(Lin, Lin,'--k')


hold off



%% Modelado x Observado (Precipitao Acumulada)

subplot_tight(1,2,2, [0.08 0.08],'XScale', 'log', 'YScale', 'log')

hold on

% Evento 1
loglog(acpIpga(ed1,1),acpOpga(ed1,1),'o','color',c(2,:))
loglog(acpIfps(ed1,1),acpOfps(ed1,1),'o','color',c(2,:))
loglog(acpItrs(ed1,1),acpOtrs(ed1,1),'o','color',c(2,:))
%loglog(acpIrgd(ed1,1),acpOrgd(ed1,1),'o','color',c(2,:))
%loglog(acpIsvp(ed1,1),acpOsvp(ed1,1),'o','color',c(2,:))
% Evento 2
loglog(acpIpga(ed2,1),acpOpga(ed2,1),'s','color',c(2,:))
loglog(acpIfps(ed2,1),acpOfps(ed2,1),'s','color',c(2,:))
loglog(acpItrs(ed2,1),acpOtrs(ed2,1),'s','color',c(2,:))
%loglog(acpIrgd(ed2,1),acpOrgd(ed2,1),'s','color',c(2,:))
%loglog(acpIsvp(ed2,1),acpOsvp(ed2,1),'s','color',c(2,:))
% Evento 3
loglog(acpIpga(ed3,1),acpOpga(ed3,1),'d','color',c(2,:))
loglog(acpIfps(ed3,1),acpOfps(ed3,1),'d','color',c(2,:))
loglog(acpItrs(ed3,1),acpOtrs(ed3,1),'d','color',c(2,:))
%loglog(acpIrgd(ed3,1),acpOrgd(ed3,1),'d','color',c(2,:))
%loglog(acpIsvp(ed3,1),acpOsvp(ed3,1),'d','color',c(2,:))
% Evento 4
%loglog(acpIpga(ed4,1),acpOpga(ed4,1),'<','color',c(2,:))
%loglog(acpIfps(ed4,1),acpOfps(ed4,1),'<','color',c(2,:))
loglog(acpItrs(ed4,1),acpOtrs(ed4,1),'<','color',c(2,:))
loglog(acpIrgd(ed4,1),acpOrgd(ed4,1),'<','color',c(2,:))
loglog(acpIsvp(ed4,1),acpOsvp(ed4,1),'<','color',c(2,:))
% Evento 5
loglog(acpIpga(ed5,1),acpOpga(ed5,1),'*','color',c(2,:))
loglog(acpIfps(ed5,1),acpOfps(ed5,1),'*','color',c(2,:))
loglog(acpItrs(ed5,1),acpOtrs(ed5,1),'*','color',c(2,:))
%loglog(acpIrgd(ed5,1),acpOrgd(ed5,1),'*','color',c(2,:))
loglog(acpIsvp(ed5,1),acpOsvp(ed5,1),'*','color',c(2,:))
% Evento 6
%loglog(acpIpga(ed6,1),acpOpga(ed6,1),'h','color',c(2,:))
%loglog(acpIfps(ed6,1),acpOfps(ed6,1),'h','color',c(2,:))
%loglog(acpItrs(ed6,1),acpOtrs(ed6,1),'h','color',c(2,:))
%loglog(acpIrgd(ed6,1),acpOrgd(ed6,1),'h','color',c(2,:))
loglog(acpIsvp(ed6,1),acpOsvp(ed6,1),'h','color',c(2,:))
% Evento 7
loglog(acpIpga(ed7,1),acpOpga(ed7,1),'+','color',c(2,:))
loglog(acpIfps(ed7,1),acpOfps(ed7,1),'+','color',c(2,:))
loglog(acpItrs(ed7,1),acpOtrs(ed7,1),'+','color',c(2,:))
loglog(acpIrgd(ed7,1),acpOrgd(ed7,1),'+','color',c(2,:))
%loglog(acpIsvp(ed7,1),acpOsvp(ed7,1),'+','color',c(2,:))
% Evento 8
loglog(acpIpga(ed8,1),acpOpga(ed8,1),'.','color',c(2,:))
loglog(acpIfps(ed8,1),acpOfps(ed8,1),'.','color',c(2,:))
loglog(acpItrs(ed8,1),acpOtrs(ed8,1),'.','color',c(2,:))
loglog(acpIrgd(ed8,1),acpOrgd(ed8,1),'.','color',c(2,:))
loglog(acpIsvp(ed8,1),acpOsvp(ed8,1),'.','color',c(2,:))
% Evento 9
loglog(acpIpga(ed9,1),acpOpga(ed9,1),'x','color',c(2,:))
%loglog(acpIfps(ed9,1),acpOfps(ed9,1),'x','color',c(2,:))
%loglog(acpItrs(ed9,1),acpOtrs(ed9,1),'x','color',c(2,:))
%loglog(acpIrgd(ed9,1),acpOrgd(ed9,1),'x','color',c(2,:))
%loglog(acpIsvp(ed9,1),acpOsvp(ed9,1),'x','color',c(2,:))
% Evento 10
loglog(acpIpga(ed10,1),acpOpga(ed10,1),'^','color',c(2,:))
loglog(acpIfps(ed10,1),acpOfps(ed10,1),'^','color',c(2,:))
loglog(acpItrs(ed10,1),acpOtrs(ed10,1),'^','color',c(2,:))
loglog(acpIrgd(ed10,1),acpOrgd(ed10,1),'^','color',c(2,:))
loglog(acpIsvp(ed10,1),acpOsvp(ed10,1),'^','color',c(2,:))
% Evento 11
loglog(acpIpga(ed11,1),acpOpga(ed11,1),'v','color',c(2,:))
loglog(acpIfps(ed11,1),acpOfps(ed11,1),'v','color',c(2,:))
loglog(acpItrs(ed11,1),acpOtrs(ed11,1),'v','color',c(2,:))
%loglog(acpIrgd(ed11,1),acpOrgd(ed11,1),'v','color',c(2,:))
%loglog(acpIsvp(ed11,1),acpOsvp(ed11,1),'v','color',c(2,:))
% Evento 12
loglog(acpIpga(ed12,1),acpOpga(ed12,1),'p','color',c(2,:))
loglog(acpIfps(ed12,1),acpOfps(ed12,1),'p','color',c(2,:))
loglog(acpItrs(ed12,1),acpOtrs(ed12,1),'p','color',c(2,:))
%loglog(acpIrgd(ed12,1),acpOrgd(ed12,1),'p','color',c(2,:))
%loglog(acpIsvp(ed12,1),acpOsvp(ed12,1),'p','color',c(2,:))

xlabel('Observation','fontsize',18)
title('Precipitation Data (mm)','fontsize',18)
a = get(gca,'XTickLabel');
set(gca,'fontsize',18)
set(gca,'XLim',[0 1000])
%set(gca,'XTick',(0:50:400))

% Linha de tendncia

Lin = linspace(10^-3,10^3);
ax2 = plot(Lin, Lin,'--k');


%print -depsc -tiff -r300 -painters obs_x_model.eps



%% Regresso Linear

figure(12)
clf

%%%%% Temperatura

subplot_tight(1,2,1,[0.08 0.08])

 
tI = [tIpga; tIfps; tItrs; tIrgd; tIsvp];
tO = [tOpga; tOfps; tOtrs; tOrgd; tOsvp];


x = tI;
y = tO;

% Deletando os dados ausentes na observacao e os correspontentes do modelo
in = find(isnan(tI));
x(in) = [];
y(in) = [];


[p,S] = polyfit(x,y,1);
f = polyval(p,x); 
plot(x,y,'o','color',c(2,:),'HandleVisibility','off')
hold on
plot(x,f,'-','color',c(2,:)) 
legend('linear fit (r2 = 0.9470)') 
A = [x y];
R=corrcoef(A);  % r2 = 0.9470
% Linha de tendncia

% Lin = linspace(0,350);
% ax2 = plot(Lin, Lin,'--k');

xlabel('Observation','fontsize',18)
ylabel('Model','fontsize',18)
title('Temperature Data (C)','fontsize',18)
a = get(gca,'XTickLabel');
set(gca,'fontsize',18)
set(gca,'XLim',[0 35])
set(gca,'XTick',(0:5:35))

%%%%% Preicpitaao

% Agrupar eventos com chuva significativa


% Paranagua
chuvaI_pga = [acpIpga(ed1,1); acpIpga(ed2,1); acpIpga(ed3,1); ...
    acpIpga(ed5,1); acpIpga(ed7,1); acpIpga(ed8,1); acpIpga(ed10,1); ...
    acpIpga(ed11,1); acpIpga(ed12,1)];

chuvaO_pga = [acpOpga(ed1,1); acpOpga(ed2,1); acpOpga(ed3,1); ...
    acpOpga(ed5,1); acpOpga(ed7,1); acpOpga(ed8,1); acpOpga(ed10,1); ...
    acpOpga(ed11,1); acpOpga(ed12,1)];

% Florianopolis
chuvaI_fps = [acpIfps(ed1,1); acpIfps(ed2,1); acpIfps(ed3,1); ...
    acpIfps(ed5,1); acpIfps(ed7,1); acpIfps(ed8,1); acpIfps(ed10,1); ...
    acpIfps(ed11,1); acpIfps(ed12,1)];

chuvaO_fps = [acpOfps(ed1,1); acpOfps(ed2,1); acpOfps(ed3,1); ...
    acpOfps(ed5,1); acpOfps(ed7,1); acpOfps(ed8,1); acpOfps(ed10,1); ...
    acpOfps(ed11,1); acpOfps(ed12,1)];


% Torres
chuvaI_trs = [acpItrs(ed1,1); acpItrs(ed2,1); acpItrs(ed3,1); ...
    acpItrs(ed5,1); acpItrs(ed7,1); acpItrs(ed8,1); acpItrs(ed10,1); ...
    acpItrs(ed11,1); acpItrs(ed12,1)];

chuvaO_trs = [acpOtrs(ed1,1); acpOtrs(ed2,1); acpOtrs(ed3,1); ...
    acpOtrs(ed5,1); acpOtrs(ed7,1); acpOtrs(ed8,1); acpOtrs(ed10,1); ...
    acpOtrs(ed11,1); acpOtrs(ed12,1)];

% Rio Grande

chuvaI_rgd = [acpIrgd(ed4,1); acpIrgd(ed7,1); acpIrgd(ed8,1); ...
    acpIrgd(ed10,1)];

chuvaO_rgd = [acpOrgd(ed4,1); acpOrgd(ed7,1); acpOrgd(ed8,1); ...
    acpOrgd(ed10,1)];

% Santa Vitoria do Palmar

chuvaI_svp = [acpIsvp(ed4,1); acpIsvp(ed5,1); acpIsvp(ed8,1); ...
    acpIsvp(ed10,1)];

chuvaO_svp = [acpOsvp(ed4,1); acpOsvp(ed5,1); acpOsvp(ed8,1); ...
    acpOsvp(ed10,1)];

% Agrupar matriz com esses eventos

acpI = [chuvaI_pga; chuvaI_fps; chuvaI_trs; chuvaI_rgd; chuvaI_svp];
acpI(isnan(acpI)) = 0;
acpO = [chuvaO_pga; chuvaO_fps; chuvaO_trs; chuvaO_rgd; chuvaO_svp];

% Aplicar a regresso linear 

subplot_tight(1,2,2,[0.08 0.08])

x = acpI;
y = acpO;


[p,S] = polyfit(x,y,1);
f = polyval(p,x); 
loglog(x,y,'o','color',c(2,:),'HandleVisibility','off')
hold on
loglog(x,f,'.','color',c(2,:)) 
legend('linear fit (r2 = 0.5556)') 
A = [x y];
R=corrcoef(A);  % r2 = 0.5556

xlabel('Observation','fontsize',18)
title('Precipitation Data (mm)','fontsize',18)
a = get(gca,'XTickLabel');
set(gca,'fontsize',18)
set(gca,'XLim',[0 350])
%set(gca,'XTick',(0:50:400))
set(gca,'YLim',[0 350])
%set(gca,'YTick',(0:50:400))

% Linha de tendncia
% 
% Lin = linspace(0,350);
% ax2 = plot(Lin, Lin,'--k');

% legend([ax1 ax2],{'Regression','Trend'},'Location','southeast');


%print -depsc -tiff -r300 -painters obs_x_model.eps

hold off

%% Modelado x Observado (Velocidade do vento)

% subplot(2,2,3)
% hold on
% 
% % Evento 1
% plot(vvIpga(eh1,1),vvOpga(eh1,1),'o','color',c(2,:))
% plot(vvIfps(eh1,1),vvOfps(eh1,1),'o','color',c(2,:))
% plot(vvItrs(eh1,1),vvOtrs(eh1,1),'o','color',c(2,:))
% plot(vvIrgd(eh1,1),vvOrgd(eh1,1),'o','color',c(2,:))
% plot(vvIsvp(eh1,1),vvOsvp(eh1,1),'o','color',c(2,:))
% % Evento 2
% plot(vvIpga(eh2,1),vvOpga(eh2,1),'s','color',c(2,:))
% plot(vvIfps(eh2,1),vvOfps(eh2,1),'s','color',c(2,:))
% plot(vvItrs(eh2,1),vvOtrs(eh2,1),'s','color',c(2,:))
% plot(vvIrgd(eh2,1),vvOrgd(eh2,1),'s','color',c(2,:))
% plot(vvIsvp(eh2,1),vvOsvp(eh2,1),'s','color',c(2,:))
% % Evento 3
% plot(vvIpga(eh3,1),vvOpga(eh3,1),'d','color',c(2,:))
% plot(vvIfps(eh3,1),vvOfps(eh3,1),'d','color',c(2,:))
% plot(vvItrs(eh3,1),vvOtrs(eh3,1),'d','color',c(2,:))
% plot(vvIrgd(eh3,1),vvOrgd(eh3,1),'d','color',c(2,:))
% plot(vvIsvp(eh3,1),vvOsvp(eh3,1),'d','color',c(2,:))
% % Evento 4
% plot(vvIpga(eh4,1),vvOpga(eh4,1),'d','color',c(2,:))
% plot(vvIfps(eh4,1),vvOfps(eh4,1),'d','color',c(2,:))
% plot(vvItrs(eh4,1),vvOtrs(eh4,1),'d','color',c(2,:))
% plot(vvIrgd(eh4,1),vvOrgd(eh4,1),'d','color',c(2,:))
% plot(vvIsvp(eh4,1),vvOsvp(eh4,1),'d','color',c(2,:))
% % Evento 5
% plot(vvIpga(eh5,1),vvOpga(eh5,1),'*','color',c(2,:))
% plot(vvIfps(eh5,1),vvOfps(eh5,1),'*','color',c(2,:))
% plot(vvItrs(eh5,1),vvOtrs(eh5,1),'*','color',c(2,:))
% plot(vvIrgd(eh5,1),vvOrgd(eh5,1),'*','color',c(2,:))
% plot(vvIsvp(eh5,1),vvOsvp(eh5,1),'*','color',c(2,:))
% % Evento 6
% plot(vvIpga(eh6,1),vvOpga(eh6,1),'*','color',c(2,:))
% plot(vvIfps(eh6,1),vvOfps(eh6,1),'*','color',c(2,:))
% plot(vvItrs(eh6,1),vvOtrs(eh6,1),'*','color',c(2,:))
% plot(vvIrgd(eh6,1),vvOrgd(eh6,1),'*','color',c(2,:))
% plot(vvIsvp(eh6,1),vvOsvp(eh6,1),'*','color',c(2,:))
% % Evento 7
% plot(vvIpga(eh7,1),vvOpga(eh7,1),'+','color',c(2,:))
% plot(vvIfps(eh7,1),vvOfps(eh7,1),'+','color',c(2,:))
% plot(vvItrs(eh7,1),vvOtrs(eh7,1),'+','color',c(2,:))
% plot(vvIrgd(eh7,1),vvOrgd(eh7,1),'+','color',c(2,:))
% plot(vvIsvp(eh7,1),vvOsvp(eh7,1),'+','color',c(2,:))
% % Evento 8
% plot(vvIpga(eh8,1),vvOpga(eh8,1),'.','color',c(2,:))
% plot(vvIfps(eh8,1),vvOfps(eh8,1),'.','color',c(2,:))
% plot(vvItrs(eh8,1),vvOtrs(eh8,1),'.','color',c(2,:))
% plot(vvIrgd(eh8,1),vvOrgd(eh8,1),'.','color',c(2,:))
% plot(vvIsvp(eh8,1),vvOsvp(eh8,1),'.','color',c(2,:))
% % Evento 9
% plot(vvIpga(eh9,1),vvOpga(eh9,1),'x','color',c(2,:))
% plot(vvIfps(eh9,1),vvOfps(eh9,1),'x','color',c(2,:))
% plot(vvItrs(eh9,1),vvOtrs(eh9,1),'x','color',c(2,:))
% plot(vvIrgd(eh9,1),vvOrgd(eh9,1),'x','color',c(2,:))
% plot(vvIsvp(eh9,1),vvOsvp(eh9,1),'x','color',c(2,:))
% % Evento 10
% plot(vvIpga(eh10,1),vvOpga(eh10,1),'^','color',c(2,:))
% plot(vvIfps(eh10,1),vvOfps(eh10,1),'^','color',c(2,:))
% plot(vvItrs(eh10,1),vvOtrs(eh10,1),'^','color',c(2,:))
% plot(vvIrgd(eh10,1),vvOrgd(eh10,1),'^','color',c(2,:))
% plot(vvIsvp(eh10,1),vvOsvp(eh10,1),'^','color',c(2,:))
% % Evento 11
% plot(vvIpga(eh11,1),vvOpga(eh11,1),'v','color',c(2,:))
% plot(vvIfps(eh11,1),vvOfps(eh11,1),'v','color',c(2,:))
% plot(vvItrs(eh11,1),vvOtrs(eh11,1),'v','color',c(2,:))
% plot(vvIrgd(eh11,1),vvOrgd(eh11,1),'v','color',c(2,:))
% plot(vvIsvp(eh11,1),vvOsvp(eh11,1),'v','color',c(2,:))
% % Evento 12
% plot(vvIpga(eh12,1),vvOpga(eh12,1),'p','color',c(2,:))
% plot(vvIfps(eh12,1),vvOfps(eh12,1),'p','color',c(2,:))
% plot(vvItrs(eh12,1),vvOtrs(eh12,1),'p','color',c(2,:))
% plot(vvIrgd(eh12,1),vvOrgd(eh12,1),'p','color',c(2,:))
% plot(vvIsvp(eh12,1),vvOsvp(eh12,1),'p','color',c(2,:))
% 
% xlabel('Observation')
% ylabel('Model')
% title('Wind Speed Data')
% 
% % Regresso Linear
% 
% vvI = [vvIpga; vvIfps; vvItrs; vvIrgd; vvIsvp];
% vvI(isnan(vvI)) = 0;
% 
% vvO = [vvOpga; vvOfps; vvOtrs; vvOrgd; vvOsvp];
% B =  vvI\vvO;
% B1 =  vvI*B;
% plot(vvI,B1,'k')
% 
% hold off

%% Modelado x Observado (Direo do vento)

% subplot(2,2,4)
% hold on
% 
% % Evento 1
% plot(dvIpga(eh1,1),dvOpga(eh1,1),'o','color',c(2,:))
% plot(dvIfps(eh1,1),dvOfps(eh1,1),'o','color',c(2,:))
% plot(dvItrs(eh1,1),dvOtrs(eh1,1),'o','color',c(2,:))
% plot(dvIrgd(eh1,1),dvOrgd(eh1,1),'o','color',c(2,:))
% plot(dvIsvp(eh1,1),dvOsvp(eh1,1),'o','color',c(2,:))
% % Evento 2
% plot(dvIpga(eh2,1),dvOpga(eh2,1),'s','color',c(2,:))
% plot(dvIfps(eh2,1),dvOfps(eh2,1),'s','color',c(2,:))
% plot(dvItrs(eh2,1),dvOtrs(eh2,1),'s','color',c(2,:))
% plot(dvIrgd(eh2,1),dvOrgd(eh2,1),'s','color',c(2,:))
% plot(dvIsvp(eh2,1),dvOsvp(eh2,1),'s','color',c(2,:))
% % Evento 3
% plot(dvIpga(eh3,1),dvOpga(eh3,1),'d','color',c(2,:))
% plot(dvIfps(eh3,1),dvOfps(eh3,1),'d','color',c(2,:))
% plot(dvItrs(eh3,1),dvOtrs(eh3,1),'d','color',c(2,:))
% plot(dvIrgd(eh3,1),dvOrgd(eh3,1),'d','color',c(2,:))
% plot(dvIsvp(eh3,1),dvOsvp(eh3,1),'d','color',c(2,:))
% % Evento 4
% plot(dvIpga(eh4,1),dvOpga(eh4,1),'d','color',c(2,:))
% plot(dvIfps(eh4,1),dvOfps(eh4,1),'d','color',c(2,:))
% plot(dvItrs(eh4,1),dvOtrs(eh4,1),'d','color',c(2,:))
% plot(dvIrgd(eh4,1),dvOrgd(eh4,1),'d','color',c(2,:))
% plot(dvIsvp(eh4,1),dvOsvp(eh4,1),'d','color',c(2,:))
% % Evento 5
% plot(dvIpga(eh5,1),dvOpga(eh5,1),'*','color',c(2,:))
% plot(dvIfps(eh5,1),dvOfps(eh5,1),'*','color',c(2,:))
% plot(dvItrs(eh5,1),dvOtrs(eh5,1),'*','color',c(2,:))
% plot(dvIrgd(eh5,1),dvOrgd(eh5,1),'*','color',c(2,:))
% plot(dvIsvp(eh5,1),dvOsvp(eh5,1),'*','color',c(2,:))
% % Evento 6
% plot(dvIpga(eh6,1),dvOpga(eh6,1),'*','color',c(2,:))
% plot(dvIfps(eh6,1),dvOfps(eh6,1),'*','color',c(2,:))
% plot(dvItrs(eh6,1),dvOtrs(eh6,1),'*','color',c(2,:))
% plot(dvIrgd(eh6,1),dvOrgd(eh6,1),'*','color',c(2,:))
% plot(dvIsvp(eh6,1),dvOsvp(eh6,1),'*','color',c(2,:))
% % Evento 7
% plot(dvIpga(eh7,1),dvOpga(eh7,1),'+','color',c(2,:))
% plot(dvIfps(eh7,1),dvOfps(eh7,1),'+','color',c(2,:))
% plot(dvItrs(eh7,1),dvOtrs(eh7,1),'+','color',c(2,:))
% plot(dvIrgd(eh7,1),dvOrgd(eh7,1),'+','color',c(2,:))
% plot(dvIsvp(eh7,1),dvOsvp(eh7,1),'+','color',c(2,:))
% % Evento 8
% plot(dvIpga(eh8,1),dvOpga(eh8,1),'.','color',c(2,:))
% plot(dvIfps(eh8,1),dvOfps(eh8,1),'.','color',c(2,:))
% plot(dvItrs(eh8,1),dvOtrs(eh8,1),'.','color',c(2,:))
% plot(dvIrgd(eh8,1),dvOrgd(eh8,1),'.','color',c(2,:))
% plot(dvIsvp(eh8,1),dvOsvp(eh8,1),'.','color',c(2,:))
% % Evento 9
% plot(dvIpga(eh9,1),dvOpga(eh9,1),'x','color',c(2,:))
% plot(dvIfps(eh9,1),dvOfps(eh9,1),'x','color',c(2,:))
% plot(dvItrs(eh9,1),dvOtrs(eh9,1),'x','color',c(2,:))
% plot(dvIrgd(eh9,1),dvOrgd(eh9,1),'x','color',c(2,:))
% plot(dvIsvp(eh9,1),dvOsvp(eh9,1),'x','color',c(2,:))
% % Evento 10
% plot(dvIpga(eh10,1),dvOpga(eh10,1),'^','color',c(2,:))
% plot(dvIfps(eh10,1),dvOfps(eh10,1),'^','color',c(2,:))
% plot(dvItrs(eh10,1),dvOtrs(eh10,1),'^','color',c(2,:))
% plot(dvIrgd(eh10,1),dvOrgd(eh10,1),'^','color',c(2,:))
% plot(dvIsvp(eh10,1),dvOsvp(eh10,1),'^','color',c(2,:))
% % Evento 11
% plot(dvIpga(eh11,1),dvOpga(eh11,1),'v','color',c(2,:))
% plot(dvIfps(eh11,1),dvOfps(eh11,1),'v','color',c(2,:))
% plot(dvItrs(eh11,1),dvOtrs(eh11,1),'v','color',c(2,:))
% plot(dvIrgd(eh11,1),dvOrgd(eh11,1),'v','color',c(2,:))
% plot(dvIsvp(eh11,1),dvOsvp(eh11,1),'v','color',c(2,:))
% % Evento 12
% plot(dvIpga(eh12,1),dvOpga(eh12,1),'p','color',c(2,:))
% plot(dvIfps(eh12,1),dvOfps(eh12,1),'p','color',c(2,:))
% plot(dvItrs(eh12,1),dvOtrs(eh12,1),'p','color',c(2,:))
% plot(dvIrgd(eh12,1),dvOrgd(eh12,1),'p','color',c(2,:))
% plot(dvIsvp(eh12,1),dvOsvp(eh12,1),'p','color',c(2,:))
% 
% xlabel('Observation')
% ylabel('Model')
% title('Wind Direction Data')
% 
% hold off



% print -depsc -tiff -r300 -painters histograms.eps

% %%%% Teste de cores
% figure(1)
% clf
% colr = linspecer(20);
% for i=1:20
% l = linspace(1,20)+i;
% hold on
% plot(l,'color',colr(i,:),'linewidth',2);
% end






